==> php-residence_0.2.4.tar.gz: php-residence/includes/lang/en/crearegole.php <==
<?php

switch ($messaggio) {

case "Inserisci le regole di assegnazione per le prenotazioni dell'anno":	$messaggio = "Insert the assignation rules for reservations of year"; break;
case "Regola di assegnazione":  		$messaggio = "Assignation rule"; break;
case "Chiedi prima di assegnare l'appartamento":	$messaggio = "Ask before assigning the apartment"; break;
case "nel periodo dal":  			$messaggio = "in the period from"; break;
case "al":  					$messaggio = "to"; break;
case "motivazione":  				$messaggio = "motivation"; break;
case "Inserisci la regola":  			$messaggio = "Insert rule"; break;
case "Cancella tutte le regole di questo tipo":	$messaggio = "Delete all rules of this kind"; break;
case "Quando si sceglie la tariffa":  		$messaggio = "When choosing fare"; break;
case "assegna automaticamente gli appartamenti":	$messaggio = "automatically assign apartments"; break;
case "lista di appartamenti separati da virgole":	$messaggio = "comma separated list of apartments"; break;
case "se non si inserisce nessun altro metodo di assegnazione":	$messaggio = "if no other method of assignation is inserted"; break;
case "Vedi le regole gi inserite":  		$messaggio = "View already inserted rules"; break;
case "Torna al men principale":  		$messaggio = "Back to main menu"; break;
case "Non sono stati inseriti tutti i dati necessari":	$messaggio = "Not all necessary data have been inserted"; break;
case "Le date sono sbagliate":  		$messaggio = "Dates are wrong"; break;
case "Esiste gi una regola di questo tipo nell'appartamento e nel periodo selezionato":	$messaggio = "A rule of this kind already exists for the apartment and period selected"; break;
case "opzionale":  				$messaggio = "optional"; break;
case "La regola  stata inserita":  		$messaggio = "The rule has been inserted"; break;
case "Sei sicuro di voler cancellare tutte le regole del tipo 1":	$messaggio = "Are you sure you want to delete all the rules of type 1"; break;
case "SI":  					$messaggio = "YES"; break;
case "Le regole sono state cancellate":  	$messaggio = "The rules have been deleted"; break;
case "Si deve scegliere la tariffa":  		$messaggio = "You must choose the fare"; break;
case "La tariffa scelta ha gi degli appartamenti associati, cancella la regola prima di inserirne una nuova":	$messaggio = "The choosen apartment has already some assigned apartments, delete the rule before inserting a new one"; break;
case "Si deve inserire almeno un appartamento da associare":	$messaggio = "You must insert at least one apartment to assign to"; break;
case "L'appartamento ":  			$messaggio = "The apartment "; break;
case " non esiste":  				$messaggio = " does not exist"; break;
case "La regola di assegnazione 2  stata inserita":	$messaggio = "The assignation rule 2 has been inserted"; break;
case "Torna indietro":  			$messaggio = "Go back"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> php-residence_0.3.tar.gz: php-residence/includes/lang/en/crearegole.php <==
<?php

switch ($messaggio) {

case "Inserisci le regole di assegnazione per le prenotazioni dell'anno":	$messaggio = "Insert the assignation rules for reservations of year"; break;
case "Regola di assegnazione":  		$messaggio = "Assignation rule"; break;
case "Chiedi prima di assegnare l'appartamento":	$messaggio = "Ask before assigning the apartment"; break;
case "nel periodo dal":  			$messaggio = "in the period from"; break;
case "al":  					$messaggio = "to"; break;
case "motivazione":  				$messaggio = "motivation"; break;
case "Inserisci la regola":  			$messaggio = "Insert rule"; break;
case "Cancella tutte le regole di questo tipo":	$messaggio = "Delete all rules of this kind"; break;
case "Quando si sceglie la tariffa":  		$messaggio = "When choosing fare"; break;
case "assegna automaticamente gli appartamenti":	$messaggio = "automatically assign apartments"; break;
case "lista di appartamenti separati da virgole":	$messaggio = "comma separated list of apartments"; break;
case "se non si inserisce nessun altro metodo di assegnazione":	$messaggio = "if no other method of assignation is inserted"; break;
case "Vedi le regole gi inserite":  		$messaggio = "View already inserted rules"; break;
case "Torna al men principale":  		$messaggio = "Back to main menu"; break;
case "Non sono stati inseriti tutti i dati necessari":	$messaggio = "Not all necessary data have been inserted"; break;
case "Le date sono sbagliate":  		$messaggio = "Dates are wrong"; break;
case "Esiste gi una regola di questo tipo nell'appartamento e nel periodo selezionato":	$messaggio = "A rule of this kind already exists for the apartment and period selected"; break;
case "opzionale":  				$messaggio = "optional"; break;
case "La regola  stata inserita":  		$messaggio = "The rule has been inserted"; break;
case "Sei sicuro di voler cancellare tutte le regole del tipo 1":	$messaggio = "Are you sure you want to delete all the rules of type 1"; break;
case "SI":  					$messaggio = "YES"; break;
case "Le regole sono state cancellate":  	$messaggio = "The rules have been deleted"; break;
case "Si deve scegliere la tariffa":  		$messaggio = "You must choose the fare"; break;
case "La tariffa scelta ha gi degli appartamenti associati, cancella la regola prima di inserirne una nuova":	$messaggio = "The choosen fare has already some assigned apartments, delete the rule before inserting a new one"; break;
case "Si deve inserire almeno un appartamento da associare":	$messaggio = "You must insert at least one apartment to assign to"; break;
case "L'appartamento ":  			$messaggio = "The apartment "; break;
case " non esiste":  				$messaggio = " does not exist"; break;
case "La regola di assegnazione 2  stata inserita":	$messaggio = "The assignation rule 2 has been inserted"; break;
case "Torna indietro":  			$messaggio = "Go back"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
